@@ -120,7 +120,7 @@ def seas_box_plot(hist, fwd=None, **kwargs):
     return fig
 
 
-def seas_table_plot(hist, fwd):
+def seas_table_plot(hist, fwd=None):
     df = cpu.seas_table(hist, fwd)
 
     colsh = list(df.columns)
@@ -213,21 +213,3 @@ def reindex_year_line_plot(df, **kwargs):
 
     return fig
 
-
-# TODO remove once transitioned over legacy code
-# Moved to commodplotutil
-def plhtml(fig, margin=cpu.narrow_margin, **kwargs):
-    """
-    Given a plotly figure, return it as a div
-    """
-    # if 'margin' in kwargs:
-    if fig is not None:
-        fig.update_layout(margin=margin)
-
-        fig.update_xaxes(automargin=True)
-        fig.update_yaxes(automargin=True)
-        return pl.plot(fig, include_plotlyjs=False, output_type='div')
-
-    return ''
-
-
